@@ -3,6 +3,9 @@ index.G1<-function(x,cl)
    	   	
         n <- length(cl)
         k <- max(cl)
+        if(is.null(dim(x))){
+          dim(x)<-c(length(x),1)
+        }
 	   centers<-matrix(nrow=k,ncol=ncol(x))
 	   for(i in 1:k)
 	   {
@@ -23,4 +26,4 @@ index.G1<-function(x,cl)
         bgss <- allmeandist - wgss
         (bgss/(k-1))/(wgss/(n-k))
 
-}
+}
\ No newline at end of file
